@@ -7,6 +7,8 @@ use Sub::Name;
 use strict;
 use warnings;
 
+our $VERSION = '0.003003';
+
 sub install_methodhandler {
   my $class = shift;
   my %args  = @_;
@@ -67,6 +69,31 @@ sub strip_attrs {
   return $attrs;
 }
 
+sub code_for {
+  my ($self, $name) = @_;
+
+  if (defined $name) {
+    my $pkg = $self->get_curstash_name;
+    $name = join( '::', $pkg, $name )
+      unless( $name =~ /::/ );
+    return sub (&) {
+      my $code = shift;
+      # So caller() gets the subroutine name
+      no strict 'refs';
+      *{$name} = subname $name => $code;
+      return;
+    };
+  } else {
+    return sub (&) { shift };
+  }
+}
+
+sub install {
+  my ($self, $name ) = @_;
+
+  $self->shadow( $self->code_for($name) );
+}
+
 sub parser {
   my $self = shift;
   $self->init(@_);
@@ -81,22 +108,13 @@ sub parser {
     $inject = $self->scope_injector_call() . $inject;
   }
   $self->inject_if_block($inject, $attrs ? "sub ${attrs} " : '');
-  if (defined $name) {
-    my $pkg = $self->get_curstash_name;
-    $name = join( '::', $pkg, $name )
-      unless( $name =~ /::/ );
-    $self->shadow( sub (&) {
-      my $code = shift;
-      # So caller() gets the subroutine name
-      no strict 'refs';
-      *{$name} = subname $name => $code;
-    });
-  } else {
-    $self->shadow(sub (&) { shift });
-  }
+
+  $self->install( $name );
+
+  return;
 }
 
-sub parse_proto { }
+sub parse_proto { '' }
 
 sub inject_parsed_proto {
   return $_[1];
